
/*
 *  Diverse Bristol midi routines.
 *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 */

/*#define DEBUG */

#include <unistd.h>
#include <stdio.h>

int
bristolPhysWrite(int fd, unsigned char *message, int size)
{
#ifdef DEBUG
	printf("bristolPhysWrite(%i, %i): %x\n", fd, size, message[0]);
#endif

	if (write(fd, message, size) != size)
	{
		//perror("midi write error");
		printf("midi write error, fd %i, size %i\n", fd, size);
		return(1);
	}

	return(0);
}

